@@ -5,25 +5,26 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Copy link" : "Kopiraj vezu",
     "Move" : "Move",
-    "Delete" : "Delete",
     "Select all" : "Označi sve",
     "New" : "Nov",
     "New folder" : "Nova fascikla",
     "Search" : "Traži",
+    "Empty trash bin" : "Isprazni kantu",
+    "_%n folder_::_%n folders_" : ["%n fascikla","%n fascikle","%n fascikli"],
     "Cancel" : "Otkaži",
     "Shared with you" : "Shared with you",
     "Files" : "Фајлови",
-    "Import" : "Uvezi",
+    "Delete" : "Delete",
     "Title" : "Naslov",
     "Link" : "Prečica",
     "Root folder" : "Korena fascikla",
     "Tags" : "Oznake",
     "Notes" : "Notes",
+    "Link copied" : "Veza iskopirana",
     "Owner" : "Vlasnik",
     "Sharing" : "Deljenje",
     "Share link" : "Podeli vezu",
     "Allow editing" : "Dozvoli uređivanje",
-    "Link copied" : "Veza iskopirana",
     "Privacy" : "Privatnost",
     "Folder" : "Folder",
     "Save" : "Save"
