@@ -3,7 +3,6 @@
 namespace OCA\Bookmarks\Tests;
 
 use OC;
-use OCA\Bookmarks\Controller\BookmarkController;
 use OCA\Bookmarks\Controller\FoldersController;
 use OCA\Bookmarks\Db\Bookmark;
 use OCA\Bookmarks\Db\BookmarkMapper;
@@ -121,7 +120,7 @@ class FolderControllerTest extends TestCase {
 		$emptyCache->method('remove')->willReturn(true);
 		$emptyCache->method('clear')->willReturn(true);
 		$this->cacheFactory = $this->createMock(ICacheFactory::class);
-		$this->cacheFactory->method('createLocal')->willReturn($this->emptyCache);
+		$this->cacheFactory->method('createDistributed')->willReturn($this->emptyCache);
 		$this->hashManager = new TreeCacheManager(
 			$this->folderMapper,
 			$this->bookmarkMapper,
@@ -221,6 +220,7 @@ class FolderControllerTest extends TestCase {
 	public function setupPublicFolder(): void {
 		$this->authorizer->setUserId($this->userId);
 		$this->publicFolder = new PublicFolder();
+		$this->publicFolder->setDescription('');
 		$this->publicFolder->setFolderId($this->folder1->getId());
 		$this->publicFolderMapper->insert($this->publicFolder);
 
@@ -267,10 +267,10 @@ class FolderControllerTest extends TestCase {
 	public function testHash(bool $useCache): void {
 		if ($useCache) {
 			$this->cacheFactory = $this->createMock(ICacheFactory::class);
-			$this->cacheFactory->method('createLocal')
+			$this->cacheFactory->method('createDistributed')
 				->willReturnCallback(fn ()
 				  => OC::$server->get(ICacheFactory::class)
-					->createLocal(time() . '' . random_int(0, 1000000))
+				  	->createDistributed(time() . '' . random_int(0, 1000000))
 				);
 		}
 
@@ -427,7 +427,7 @@ class FolderControllerTest extends TestCase {
 
 		$this->setupBookmarks();
 		$this->authorizer->setUserId($this->userId);
-		$output = $this->controller->deleteFolder($this->folder1->getId());
+		$output = $this->controller->deleteFolder($this->folder1->getId(), true);
 		$data = $output->getData();
 		$this->assertEquals('success', $data['status'], var_export($data, true));
 		$output = $this->controller->getFolder($this->folder1->getId());
@@ -708,7 +708,7 @@ class FolderControllerTest extends TestCase {
 		$this->authorizer->setUserId(null);
 		$output = $this->public->deleteFolder($this->folder1->getId());
 		$data = $output->getData();
-		$this->assertEquals('error', $data['status'], var_export($data, true));
+		$this->assertEquals('success', $data['status'], var_export($data, true));
 		$output = $this->public->getFolder($this->folder1->getId());
 		$data = $output->getData();
 		$this->assertEquals('success', $data['status'], var_export($data, true));
@@ -776,7 +776,7 @@ class FolderControllerTest extends TestCase {
 		$this->authorizer->setUserId(null);
 		$output = $this->public->getFolders($this->folder1->getId(), -1);
 		$data = $output->getData();
-		$this->assertCount(1, $data['data']);
+		$this->assertCount(1, $data['data'], var_export($data['data'], true));
 		$this->assertEquals('bar', $data['data'][0]['title']);
 		$this->assertCount(0, $data['data'][0]['children']);
 	}
@@ -879,7 +879,7 @@ class FolderControllerTest extends TestCase {
 		$this->setupBookmarks();
 		$this->setupSharedFolder();
 		$this->authorizer->setUserId($this->otherUserId);
-		$output = $this->otherController->deleteFolder($this->folder1->getId());
+		$output = $this->otherController->deleteFolder($this->folder1->getId(), true);
 		$data = $output->getData();
 		$this->assertEquals('success', $data['status'], var_export($data, true));
 		$output = $this->otherController->getFolder($this->folder1->getId());
@@ -1118,7 +1118,8 @@ class FolderControllerTest extends TestCase {
 		if ($canShare) {
 			$this->assertEquals('success', $data['status'], var_export($data, true));
 		} else {
-			$this->assertEquals('error', $data['status'], var_export($data, true));
+			$this->assertEquals('success', $data['status'], var_export($data, true));
+			$this->shareMapper->find($shareId);
 		}
 	}
 
